Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1221)

Unified Diff: chrome/browser/chromeos/settings/device_settings_cache.h

Issue 10832035: Switch from SignedSettings to DeviceSettingsService. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/settings/device_settings_cache.h
diff --git a/chrome/browser/chromeos/settings/signed_settings_cache.h b/chrome/browser/chromeos/settings/device_settings_cache.h
similarity index 55%
rename from chrome/browser/chromeos/settings/signed_settings_cache.h
rename to chrome/browser/chromeos/settings/device_settings_cache.h
index ab9da594f2b58bfd0d25038b4117719538225997..8f6f7cfd58621e773dcf7d0e5f0870457585f99e 100644
--- a/chrome/browser/chromeos/settings/signed_settings_cache.h
+++ b/chrome/browser/chromeos/settings/device_settings_cache.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_SETTINGS_SIGNED_SETTINGS_CACHE_H_
-#define CHROME_BROWSER_CHROMEOS_SETTINGS_SIGNED_SETTINGS_CACHE_H_
+#ifndef CHROME_BROWSER_CHROMEOS_SETTINGS_DEVICE_SETTINGS_CACHE_H_
+#define CHROME_BROWSER_CHROMEOS_SETTINGS_DEVICE_SETTINGS_CACHE_H_
namespace enterprise_management {
class PolicyData;
@@ -13,11 +13,11 @@ class PrefService;
namespace chromeos {
-// There is need (metrics at OOBE stage) to store settings
-// (that normally would go into SignedSettings storage)
-// before owner has been assigned (hence no key is available).
-// This set of functions serves as a transient storage in that case.
-namespace signed_settings_cache {
+// There is need (metrics at OOBE stage) to store settings (that normally would
+// go into DeviceSettings storage) before owner has been assigned (hence no key
+// is available). This set of functions serves as a transient storage in that
+// case.
+namespace device_settings_cache {
// Registers required pref section.
void RegisterPrefs(PrefService* local_state);
@@ -29,11 +29,11 @@ bool Store(const enterprise_management::PolicyData &policy,
bool Retrieve(enterprise_management::PolicyData *policy,
PrefService* local_state);
// Call this after owner has been assigned to persist settings
// into SignedSettings storage.
void Finalize(PrefService* local_state);
-} // namespace signed_settings_cache
+} // namespace device_settings_cache
} // namespace chromeos
-#endif // CHROME_BROWSER_CHROMEOS_SETTINGS_SIGNED_SETTINGS_CACHE_H_
+#endif // CHROME_BROWSER_CHROMEOS_SETTINGS_DEVICE_SETTINGS_CACHE_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -29,11 +29,11 @@ bool Store(const enterprise_management::PolicyData &policy,
bool Retrieve(enterprise_management::PolicyData *policy,
PrefService* local_state);
-// Call this after owner has been assigned to persist settings
-// into SignedSettings storage.
+// Call this after owner has been assigned to persist settings into
+// DeviceSettings storage.
void Finalize(PrefService* local_state);